summaryrefslogtreecommitdiffstats
path: root/kolourpaint/widgets/kptoolwidgetbrush.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kolourpaint/widgets/kptoolwidgetbrush.cpp')
-rw-r--r--kolourpaint/widgets/kptoolwidgetbrush.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/kolourpaint/widgets/kptoolwidgetbrush.cpp b/kolourpaint/widgets/kptoolwidgetbrush.cpp
index 1e53891e..69445905 100644
--- a/kolourpaint/widgets/kptoolwidgetbrush.cpp
+++ b/kolourpaint/widgets/kptoolwidgetbrush.cpp
@@ -52,14 +52,14 @@ static int brushSize [][3] =
#define BRUSH_SIZE_NUM_COLS (int (sizeof (brushSize [0]) / sizeof (brushSize [0][0])))
#define BRUSH_SIZE_NUM_ROWS (int (sizeof (brushSize) / sizeof (brushSize [0])))
-kpToolWidgetBrush::kpToolWidgetBrush (TQWidget *parent, const char *name)
- : kpToolWidgetBase (parent, name)
+kpToolWidgetBrush::kpToolWidgetBrush (TQWidget *tqparent, const char *name)
+ : kpToolWidgetBase (tqparent, name)
{
setInvertSelectedPixmap ();
TQPixmap *pm = m_brushBitmaps;
- for (int shape = 0; shape < BRUSH_SIZE_NUM_ROWS; shape++)
+ for (int tqshape = 0; tqshape < BRUSH_SIZE_NUM_ROWS; tqshape++)
{
for (int i = 0; i < BRUSH_SIZE_NUM_COLS; i++)
{
@@ -68,7 +68,7 @@ kpToolWidgetBrush::kpToolWidgetBrush (TQWidget *parent, const char *name)
pm->resize ((w <= 0 ? width () : w),
(h <= 0 ? height () : h));
- const int s = brushSize [shape][i];
+ const int s = brushSize [tqshape][i];
TQRect rect;
if (s >= pm->width () || s >= pm->height ())
@@ -85,14 +85,14 @@ kpToolWidgetBrush::kpToolWidgetBrush (TQWidget *parent, const char *name)
kdDebug () << "kpToolWidgetBrush::kpToolWidgetBrush() rect=" << rect << endl;
#endif
- pm->fill (Qt::white);
+ pm->fill (TQt::white);
TQPainter painter (pm);
- painter.setPen (Qt::black);
- painter.setBrush (Qt::black);
+ painter.setPen (TQt::black);
+ painter.setBrush (TQt::black);
// sync: <brushes>
- switch (shape)
+ switch (tqshape)
{
case 0:
painter.drawEllipse (rect);
@@ -110,7 +110,7 @@ kpToolWidgetBrush::kpToolWidgetBrush (TQWidget *parent, const char *name)
painter.end ();
pm->setMask (pm->createHeuristicMask ());
- addOption (*pm, brushName (shape, i)/*tooltip*/);
+ addOption (*pm, brushName (tqshape, i)/*tooltip*/);
pm++;
}
@@ -127,38 +127,38 @@ kpToolWidgetBrush::~kpToolWidgetBrush ()
// private
-TQString kpToolWidgetBrush::brushName (int shape, int whichSize)
+TQString kpToolWidgetBrush::brushName (int tqshape, int whichSize)
{
- int s = brushSize [shape][whichSize];
+ int s = brushSize [tqshape][whichSize];
if (s == 1)
return i18n ("1x1");
- TQString shapeName;
+ TQString tqshapeName;
// sync: <brushes>
- switch (shape)
+ switch (tqshape)
{
case 0:
- shapeName = i18n ("Circle");
+ tqshapeName = i18n ("Circle");
break;
case 1:
- shapeName = i18n ("Square");
+ tqshapeName = i18n ("Square");
break;
case 2:
- // TODO: is this really the name of a shape? :)
- shapeName = i18n ("Slash");
+ // TODO: is this really the name of a tqshape? :)
+ tqshapeName = i18n ("Slash");
break;
case 3:
- // TODO: is this really the name of a shape? :)
- shapeName = i18n ("Backslash");
+ // TODO: is this really the name of a tqshape? :)
+ tqshapeName = i18n ("Backslash");
break;
}
- if (shapeName.isEmpty ())
- return TQString::null;
+ if (tqshapeName.isEmpty ())
+ return TQString();
- return i18n ("%1x%2 %3").arg (s).arg (s).arg (shapeName);
+ return i18n ("%1x%2 %3").arg (s).arg (s).arg (tqshapeName);
}
TQPixmap kpToolWidgetBrush::brush () const